@@ -56,12 +56,15 @@ class Checker():
   QUEUE_SIZE = 20
   SAVE_INT = 100
 
-  def __init__(self):
+  def __init__(self, **cfg):
 
     self.data = {}
     self.links = {}
     self.json_filename = None
 
+    self.exclude_status = (cfg['exclude_status'] if 'exclude_status' in cfg
+                           else (None, 200))
+
     # User-Agent for some website like Wikipedia. Without it, most of requests
     # result in 403.
     self.HEADERS = {
@@ -513,7 +516,7 @@ class Checker():
 
   def print_report_link(self, url, link):
 
-    if link['status'] in (None, '200', 'SCH', 'SKP'):
+    if link['status'] in self.exclude_status:
       return
     self.format_status(url, link)
     self.print_report_link_data(url, link)
@@ -543,7 +546,7 @@ class Checker():
       nlinks = sum(1 for l in links)
       data2.append((status, nlinks))
 
-    l = max(self.num_len(item[1]) for item in data2)
+    l = max(self.num_len(item[1]) for item in data2) if data2 else 0
 
     for status, nlinks in data2:
       print('{} {:{l},d} links'.format(self.color_status(status), nlinks, l=l))
